@@ -1,7 +1,7 @@
 """Picker button class."""
 import wx
 import os
-from ..messages import dirpickermsg, filepickermsg
+from ..dialogs.msg_dialogs import dirpickermsg, filepickermsg
 
 PickChangeEvent, EVT_PICK_CHANGE = wx.lib.newevent.NewEvent()
 
@@ -18,7 +18,7 @@ def pick_extend(instance, extension):
     )
 
 
-class PickButton(object):
+class PickButton:
     """Directory pick button."""
 
     DIR_TYPE = 0
@@ -56,6 +56,15 @@ class PickButton(object):
         self.Bind(EVT_PICK_CHANGE, self.on_change)
         self.pick_change_callback = pick_change_evt
 
+    def AcceptsFocus(self):
+        """
+        Check if we should accept focus.
+
+        If the button is hidden, we should not allow focus.
+        """
+
+        return self.IsShown()
+
     def on_change(self, event):
         """If the directory has changed call the callback given."""
 
