@@ -23,7 +23,6 @@ IN THE SOFTWARE.
 """
 import wx
 import re
-import sys
 from collections import namedtuple
 from wx.lib.embeddedimage import PyEmbeddedImage
 
@@ -1269,18 +1268,12 @@ class Messages(wx.Dialog):
             if icn is not None:
                 # We use a large icon size but half it so it will
                 # work on retina.
-                if sys.platform == "darwin":
-                    bm = icn.GetBitmap()
-                    bm.SetHeight(DEFAULT_ICON_SIZE)
-                    bm.SetWidth(DEFAULT_ICON_SIZE)
-                    icon = MessageIcon(bm, DEFAULT_ICON_SIZE, DEFAULT_ICON_SIZE)
-                else:
-                    scaled = icn.GetImage().Rescale(DEFAULT_ICON_SIZE, DEFAULT_ICON_SIZE)
-                    icon = MessageIcon(
-                        scaled.ConvertToBitmap(),
-                        DEFAULT_ICON_SIZE,
-                        DEFAULT_ICON_SIZE
-                    )
+                scaled = icn.GetImage().Rescale(DEFAULT_ICON_SIZE, DEFAULT_ICON_SIZE)
+                icon = MessageIcon(
+                    scaled.ConvertToBitmap(),
+                    DEFAULT_ICON_SIZE,
+                    DEFAULT_ICON_SIZE
+                )
 
         return icon
 
